PlotItem — pyqtgraph 0.11.0rc0 documentation

# PlotItem

class `pyqtgraph.` `PlotItem`

  GraphicsWidget implementing a standard 2D plotting area with axes.

  Bases: `GraphicsWidget`

  This class provides the ViewBox-plus-axes that appear when using `pg.plot()`, `PlotWidget`, and `GraphicsLayoutWidget.addPlot()`.

  It’s main functionality is:

  - Manage placement of ViewBox, AxisItems, and LabelItems

  - Create and manage a list of PlotDataItems displayed inside the ViewBox

  - Implement a context menu with commonly used display and analysis options

  Use `plot()` to create a new PlotDataItem and add it to the view. Use `addItem()` to add any QGraphicsItem to the view.

  This class wraps several methods from its internal ViewBox: `setXRange`, `setYRange`, `setRange`, `autoRange`, `setXLink`, `setYLink`, `setAutoPan`, `setAutoVisible`, `setLimits`, `viewRect`, `viewRange`, `setMouseEnabled`, `enableAutoRange`, `disableAutoRange`, `setAspectLocked`, `invertY`, `invertX`, `register`, `unregister`

  The ViewBox itself can be accessed by calling `getViewBox()`

  Signals: |
  sigYRangeChanged | wrapped from `ViewBox`
  sigXRangeChanged | wrapped from `ViewBox`
  sigRangeChanged | wrapped from `ViewBox`

  `__init__`(parent=None, name=None, labels=None, title=None, viewBox=None, axisItems=None, enableMenu=True, **kargs)

    Create a new PlotItem. All arguments are optional. Any extra keyword arguments are passed to PlotItem.plot().

    Arguments: |
    title | Title to display at the top of the item. Html is allowed.
    labels | A dictionary specifying the axis labels to display:
        {'left': (args), 'bottom': (args), ...}
    The name of each axis and the corresponding arguments are passed to `PlotItem.setLabel()` Optionally, PlotItem my also be initialized with the keyword arguments left, right, top, or bottom to achieve the same effect.
    name | Registers a name for this view so that others may link to it
    viewBox | If specified, the PlotItem will be constructed with this as its ViewBox.
    axisItems | Optional dictionary instructing the PlotItem to use pre-constructed items for its axes. The dict keys must be axis names (‘left’, ‘bottom’, ‘right’, ‘top’) and the values must be instances of AxisItem (or at least compatible with AxisItem).

  `addItem`(item, *args, **kargs)

    Add a graphics item to the view box. If the item has plot data (PlotDataItem, PlotCurveItem, ScatterPlotItem), it may be included in analysis performed by the PlotItem.

  `addLegend`(size=None, offset=(30, 30))

    Create a new LegendItem and anchor it over the internal ViewBox. Plots will be automatically displayed in the legend if they are created with the ‘name’ argument.

    If a LegendItem has already been created using this method, that item will be returned rather than creating a new one.

  `addLine`(x=None, y=None, z=None, **kwds)

    Create an InfiniteLine and add to the plot.

    If x is specified, the line will be vertical. If y is specified, the line will be horizontal. All extra keyword arguments are passed to `InfiniteLine.__init__()`. Returns the item created.

  `clear`()

    Remove all items from the ViewBox.

  `close`(self) → bool
  `enableAutoScale`()

    Enable auto-scaling. The plot will continuously scale to fit the boundaries of its data.

  `getAxis`(name)

    Return the specified AxisItem. name should be ‘left’, ‘bottom’, ‘top’, or ‘right’.

  `getViewBox`()

    Return the `ViewBox` contained within.

  `hideAxis`(axis)

    Hide one of the PlotItem’s axes. (‘left’, ‘bottom’, ‘right’, or ‘top’)

  `hideButtons`()

    Causes auto-scale button (‘A’ in lower-left corner) to be hidden for this PlotItem

  `listDataItems`()

    Return a list of all data items (PlotDataItem, PlotCurveItem, ScatterPlotItem, etc) contained in this PlotItem.

  `plot`(*args, **kargs)

    Add and return a new plot. See `PlotDataItem.__init__` for data arguments

    Extra allowed arguments are:

      clear - clear all plots before displaying new data params - meta-parameters to associate with this data

  `removeItem`(item)

    Remove an item from the internal ViewBox.

  `resizeEvent`(self, event: PySide2.QtWidgets.QGraphicsSceneResizeEvent)
  `setClipToView`(clip)

    Set the default clip-to-view mode for all PlotDataItems managed by this plot. If clip is True, then PlotDataItems will attempt to draw only points within the visible range of the ViewBox.

  `setDownsampling`(ds=None, auto=None, mode=None)

    Change the default downsampling mode for all PlotDataItems managed by this plot.

    Arguments: |
    ds | (int) Reduce visible plot samples by this factor, or (bool) To enable/disable downsampling without changing the value.
    auto | (bool) If True, automatically pick ds based on visible range
    mode | ‘subsample’: Downsample by taking the first of N samples. This method is fastest and least accurate. ‘mean’: Downsample by taking the mean of N samples. ‘peak’: Downsample by drawing a saw wave that follows the min and max of the original data. This method produces the best visual representation of the data but is slower.

  `setExportMode`(export, opts=None)

    This method is called by exporters to inform items that they are being drawn for export with a specific set of options. Items access these via self._exportOptions. When exporting is complete, _exportOptions is set to False.

  `setLabel`(axis, text=None, units=None, unitPrefix=None, **args)

    Set the label for an axis. Basic HTML formatting is allowed.

    Arguments: |
    axis | must be one of ‘left’, ‘bottom’, ‘right’, or ‘top’
    text | text to display along the axis. HTML allowed.
    units | units to display after the title. If units are given, then an SI prefix will be automatically appended and the axis values will be scaled accordingly. (ie, use ‘V’ instead of ‘mV’; ‘m’ will be added automatically)

  `setLabels`(**kwds)

    Convenience function allowing multiple labels and/or title to be set in one call. Keyword arguments can be ‘title’, ‘left’, ‘bottom’, ‘right’, or ‘top’. Values may be strings or a tuple of arguments to pass to setLabel.

  `setLogMode`(x=None, y=None)

    Set log scaling for x and/or y axes. This informs PlotDataItems to transform logarithmically and switches the axes to use log ticking.

    Note that no other items in the scene will be affected by this; there is (currently) no generic way to redisplay a GraphicsItem with log coordinates.

  `setMenuEnabled`(enableMenu=True, enableViewBoxMenu='same')

    Enable or disable the context menu for this PlotItem. By default, the ViewBox’s context menu will also be affected. (use enableViewBoxMenu=None to leave the ViewBox unchanged)

  `setTitle`(title=None, **args)

    Set the title of the plot. Basic HTML formatting is allowed. If title is None, then the title will be hidden.

  `showAxis`(axis, show=True)

    Show or hide one of the plot’s axes. axis must be one of ‘left’, ‘bottom’, ‘right’, or ‘top’

  `showButtons`()

    Causes auto-scale button (‘A’ in lower-left corner) to be visible for this PlotItem

  `showGrid`(x=None, y=None, alpha=None)

    Show or hide the grid for either axis.

    Arguments: |
    x | (bool) Whether to show the X grid
    y | (bool) Whether to show the Y grid
    alpha | (0.0-1.0) Opacity of the grid

  `showLabel`(axis, show=True)

    Show or hide one of the plot’s axis labels (the axis itself will be unaffected). axis must be one of ‘left’, ‘bottom’, ‘right’, or ‘top’

  `viewGeometry`()

    Return the screen geometry of the viewbox